@@ -1,7 +1,7 @@
 #
 # This file is part of the PyMeasure package.
 #
-# Copyright (c) 2013-2020 PyMeasure Developers
+# Copyright (c) 2013-2022 PyMeasure Developers
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -22,17 +22,17 @@
 # THE SOFTWARE.
 #
 
-import pytest
-from unittest import mock
+# import pytest
+# from unittest import mock
 
-from pymeasure.display.Qt import QtGui, QtCore
-from pymeasure.display.plotter import Plotter
-from pymeasure.experiment.results import Results
+# from pymeasure.display.Qt import QtGui, QtCore
+# from pymeasure.display.plotter import Plotter
+# from pymeasure.experiment.results import Results
 
 # TODO: Repair this unit test
 # class TestPlotter:
 #     # TODO: More thorough unit (or integration?) tests.
-# 
+#
 #     @mock.patch('pymeasure.display.plotter.PlotterWindow')
 #     @mock.patch('pymeasure.display.plotter.QtGui')
 #     @mock.patch.object(Plotter, 'setup_plot')
